@@ -11,9 +11,11 @@ Authors: panxu(panxu@baidu.com)
 Date:    2020/06/25 09:57:00
 """
 
-from .general_pretrained_word_embedding_loader import GeneralPretrainedWordEmbeddingLoader
+from easytext.component.register import EasytextRegister
+from easytext.data.pretrained_word_embedding_loader import GeneralPretrainedWordEmbeddingLoader
 
 
+@EasytextRegister.register("GloveLoader")
 class GloveLoader(GeneralPretrainedWordEmbeddingLoader):
     """
     Glove Word Embedding Loader.
