@@ -13,5 +13,5 @@ Date:    2020/05/16 00:33:00
 from .metric_tracker import MetricTracker
 from .record import Record
 from .trainer import Trainer
-from .config_factory import ConfigFactory
+from .config import Config
 
